package com.srs.routine.mapper;

import java.util.List;

import com.srs.routine.domain.SysDisMate;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;

/**
 * 退伍复学材料Mapper接口
 *
 * @author srs
 * @date 2025-10-28
 */
public interface SysDisMateMapper extends BaseMapper<SysDisMate> {
    /**
     * 查询退伍复学材料
     *
     * @param id 退伍复学材料主键
     * @return 退伍复学材料
     */
    public SysDisMate selectSysDisMateById(Long id);

    /**
     * 查询退伍复学材料列表
     *
     * @param sysDisMate 退伍复学材料
     * @return 退伍复学材料集合
     */
    List<SysDisMate> selectSysDisMateList(SysDisMate sysDisMate);

    /**
     * 新增退伍复学材料
     *
     * @param sysDisMate 退伍复学材料
     * @return 结果
     */
    int insertSysDisMate(SysDisMate sysDisMate);

    /**
     * 修改退伍复学材料
     *
     * @param sysDisMate 退伍复学材料
     * @return 结果
     */
    int updateSysDisMate(SysDisMate sysDisMate);

    // 新增：按学号更新子表
    int updateSysDisMateByStId(SysDisMate sysDisMate);

    /**
     * 删除退伍复学材料
     *
     * @param id 退伍复学材料主键
     * @return 结果
     */
    int deleteSysDisMateById(Long id);

    /**
     * 批量删除退伍复学材料
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteSysDisMateByIds(Long[] ids);
}
